---
name: Bug
about: Report an error or program crash
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the issue**
_A short description of what the issue is_

**Expected behaviour**
_What you expected to happen_

**Actual behaviour**
_What actually happened, error messages go here_

**To Reproduce**
_Steps to reproduce the behaviour:_
1.
2.
...

**System Information:**
_Please update accordingly_
 - Operating System: [`macOS-10.14.14`]:
 - `snmachine` Version: [`0.1.0`]
 - Occurred on which branch and with what commit: [`master-abc456d`]

**Screenshots**
_If applicable, add screenshots to help explain your problem_

**Additional context**
Add any other context about the problem here.
